@@ -1,5 +1,6 @@
 # type: ignore
 
+from datetime import time
 import os
 
 import pymysql
@@ -25,6 +26,22 @@ def assert_result_equal(result, title=None, rows=None, headers=None, status=None
         assert result == [fields]
 
 
+@dbtest
+def test_timediff_negative_value(executor):
+    sql = "select timediff('2020-11-11 01:01:01', '2020-11-11 01:02:01')"
+    result = run(executor, sql)
+    # negative value comes back as str
+    assert result[0]["rows"][0][0] == "-00:01:00"
+
+
+@dbtest
+def test_timediff_positive_value(executor):
+    sql = "select timediff('2020-11-11 01:02:01', '2020-11-11 01:01:01')"
+    result = run(executor, sql)
+    # positive value comes back as datetime.time
+    assert result[0]["rows"][0][0] == time(0, 1)
+
+
 @dbtest
 def test_get_result_status_without_warning(executor):
     sql = "select 1"
